# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.audio_stream.opus_decoder import opus_decoder_service_pb2 as cogneed__protos_dot_audio__stream_dot_opus__decoder_dot_opus__decoder__service__pb2


class OpusDecoderServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.convert = channel.unary_unary(
        '/ai.cogneed.cloud.speech.v1.OpusDecoderService/convert',
        request_serializer=cogneed__protos_dot_audio__stream_dot_opus__decoder_dot_opus__decoder__service__pb2.DecodeRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_opus__decoder_dot_opus__decoder__service__pb2.DecodeResponse.FromString,
        )


class OpusDecoderServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def convert(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_OpusDecoderServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'convert': grpc.unary_unary_rpc_method_handler(
          servicer.convert,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_opus__decoder_dot_opus__decoder__service__pb2.DecodeRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_opus__decoder_dot_opus__decoder__service__pb2.DecodeResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.cloud.speech.v1.OpusDecoderService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
