# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/trainui/config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/trainui/config.proto',
  package='ai.cogneed.api.trainui.config',
  syntax='proto3',
  serialized_options=_b('\n\035ai.cogneed.api.trainui.configP\001'),
  serialized_pb=_b('\n2cogneed-protos/ai/cogneed/api/trainui/config.proto\x12\x1d\x61i.cogneed.api.trainui.config\x1a*cogneed-protos/ai/cogneed/api/common.proto\"\xa3\x01\n\x06\x43onfig\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x15\n\ruse_case_uuid\x18\x02 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\x05\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\x03\x12\x12\n\nupdated_at\x18\x08 \x01(\x03\"K\n\x0cUpdateTarget\x12\x15\n\ruse_case_uuid\x18\x01 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\x05\":\n\x0bReadRequest\x12\x15\n\ruse_case_uuid\x18\x01 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x02 \x01(\t2\xbe\x01\n\rConfigService\x12Y\n\x04read\x12*.ai.cogneed.api.trainui.config.ReadRequest\x1a%.ai.cogneed.api.trainui.config.Config\x12R\n\x06update\x12+.ai.cogneed.api.trainui.config.UpdateTarget\x1a\x1b.ai.cogneed.api.AckResponseB!\n\x1d\x61i.cogneed.api.trainui.configP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])




_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='ai.cogneed.api.trainui.config.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.trainui.config.Config.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.trainui.config.Config.use_case_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.trainui.config.Config.keyword_uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='ai.cogneed.api.trainui.config.Config.target', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='ai.cogneed.api.trainui.config.Config.created_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_by', full_name='ai.cogneed.api.trainui.config.Config.updated_by', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='ai.cogneed.api.trainui.config.Config.created_at', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='ai.cogneed.api.trainui.config.Config.updated_at', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=293,
)


_UPDATETARGET = _descriptor.Descriptor(
  name='UpdateTarget',
  full_name='ai.cogneed.api.trainui.config.UpdateTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.trainui.config.UpdateTarget.use_case_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.trainui.config.UpdateTarget.keyword_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='ai.cogneed.api.trainui.config.UpdateTarget.target', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=370,
)


_READREQUEST = _descriptor.Descriptor(
  name='ReadRequest',
  full_name='ai.cogneed.api.trainui.config.ReadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.trainui.config.ReadRequest.use_case_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.trainui.config.ReadRequest.keyword_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=430,
)

DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.message_types_by_name['UpdateTarget'] = _UPDATETARGET
DESCRIPTOR.message_types_by_name['ReadRequest'] = _READREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), dict(
  DESCRIPTOR = _CONFIG,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.config_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.config.Config)
  ))
_sym_db.RegisterMessage(Config)

UpdateTarget = _reflection.GeneratedProtocolMessageType('UpdateTarget', (_message.Message,), dict(
  DESCRIPTOR = _UPDATETARGET,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.config_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.config.UpdateTarget)
  ))
_sym_db.RegisterMessage(UpdateTarget)

ReadRequest = _reflection.GeneratedProtocolMessageType('ReadRequest', (_message.Message,), dict(
  DESCRIPTOR = _READREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.config_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.config.ReadRequest)
  ))
_sym_db.RegisterMessage(ReadRequest)


DESCRIPTOR._options = None

_CONFIGSERVICE = _descriptor.ServiceDescriptor(
  name='ConfigService',
  full_name='ai.cogneed.api.trainui.config.ConfigService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=433,
  serialized_end=623,
  methods=[
  _descriptor.MethodDescriptor(
    name='read',
    full_name='ai.cogneed.api.trainui.config.ConfigService.read',
    index=0,
    containing_service=None,
    input_type=_READREQUEST,
    output_type=_CONFIG,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='update',
    full_name='ai.cogneed.api.trainui.config.ConfigService.update',
    index=1,
    containing_service=None,
    input_type=_UPDATETARGET,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONFIGSERVICE)

DESCRIPTOR.services_by_name['ConfigService'] = _CONFIGSERVICE

# @@protoc_insertion_point(module_scope)
