# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/predict/eval/eval_prediction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/predict/eval/eval_prediction.proto',
  package='ai.cogneed.api.predict.eval',
  syntax='proto3',
  serialized_options=_b('\n\033ai.cogneed.api.predict.evalP\001'),
  serialized_pb=_b('\n@cogneed-protos/ai/cogneed/api/predict/eval/eval_prediction.proto\x12\x1b\x61i.cogneed.api.predict.eval\x1a*cogneed-protos/ai/cogneed/api/common.proto\"6\n\x11\x45valuationMetrics\x12\x11\n\tprecision\x18\x01 \x01(\x02\x12\x0e\n\x06recall\x18\x02 \x01(\x02\"p\n\nSetRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x0f\n\x07keyword\x18\x02 \x01(\t\x12=\n\x05value\x18\x03 \x01(\x0b\x32..ai.cogneed.api.predict.eval.EvaluationMetrics\"1\n\nGetRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"M\n\x0bGetResponse\x12>\n\x06result\x18\x01 \x01(\x0b\x32..ai.cogneed.api.predict.eval.EvaluationMetrics2\xbb\x01\n\x12PredictEvalService\x12X\n\x03Get\x12\'.ai.cogneed.api.predict.eval.GetRequest\x1a(.ai.cogneed.api.predict.eval.GetResponse\x12K\n\x03Set\x12\'.ai.cogneed.api.predict.eval.SetRequest\x1a\x1b.ai.cogneed.api.AckResponseB\x1f\n\x1b\x61i.cogneed.api.predict.evalP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])




_EVALUATIONMETRICS = _descriptor.Descriptor(
  name='EvaluationMetrics',
  full_name='ai.cogneed.api.predict.eval.EvaluationMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='precision', full_name='ai.cogneed.api.predict.eval.EvaluationMetrics.precision', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recall', full_name='ai.cogneed.api.predict.eval.EvaluationMetrics.recall', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=195,
)


_SETREQUEST = _descriptor.Descriptor(
  name='SetRequest',
  full_name='ai.cogneed.api.predict.eval.SetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.predict.eval.SetRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.predict.eval.SetRequest.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai.cogneed.api.predict.eval.SetRequest.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=309,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='ai.cogneed.api.predict.eval.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.predict.eval.GetRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.predict.eval.GetRequest.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=360,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='ai.cogneed.api.predict.eval.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='ai.cogneed.api.predict.eval.GetResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=362,
  serialized_end=439,
)

_SETREQUEST.fields_by_name['value'].message_type = _EVALUATIONMETRICS
_GETRESPONSE.fields_by_name['result'].message_type = _EVALUATIONMETRICS
DESCRIPTOR.message_types_by_name['EvaluationMetrics'] = _EVALUATIONMETRICS
DESCRIPTOR.message_types_by_name['SetRequest'] = _SETREQUEST
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EvaluationMetrics = _reflection.GeneratedProtocolMessageType('EvaluationMetrics', (_message.Message,), dict(
  DESCRIPTOR = _EVALUATIONMETRICS,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.eval.eval_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.eval.EvaluationMetrics)
  ))
_sym_db.RegisterMessage(EvaluationMetrics)

SetRequest = _reflection.GeneratedProtocolMessageType('SetRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.eval.eval_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.eval.SetRequest)
  ))
_sym_db.RegisterMessage(SetRequest)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.eval.eval_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.eval.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.eval.eval_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.eval.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)


DESCRIPTOR._options = None

_PREDICTEVALSERVICE = _descriptor.ServiceDescriptor(
  name='PredictEvalService',
  full_name='ai.cogneed.api.predict.eval.PredictEvalService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=442,
  serialized_end=629,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='ai.cogneed.api.predict.eval.PredictEvalService.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Set',
    full_name='ai.cogneed.api.predict.eval.PredictEvalService.Set',
    index=1,
    containing_service=None,
    input_type=_SETREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTEVALSERVICE)

DESCRIPTOR.services_by_name['PredictEvalService'] = _PREDICTEVALSERVICE

# @@protoc_insertion_point(module_scope)
