# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/predict/bulk/bulk_prediction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/predict/bulk/bulk_prediction.proto',
  package='ai.cogneed.api.predict.bulk',
  syntax='proto3',
  serialized_options=_b('\n\033ai.cogneed.api.predict.bulkP\001'),
  serialized_pb=_b('\n@cogneed-protos/ai/cogneed/api/predict/bulk/bulk_prediction.proto\x12\x1b\x61i.cogneed.api.predict.bulk\"I\n\x14\x42ulkDetectionRequest\x12\x10\n\x08gcs_path\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\x12\r\n\x05major\x18\x03 \x01(\t\")\n\x18PredictDetectionResponse\x12\r\n\x05index\x18\x01 \x03(\t2\x91\x01\n\x14\x42ulkDetectionService\x12y\n\rGetDetections\x12\x31.ai.cogneed.api.predict.bulk.BulkDetectionRequest\x1a\x35.ai.cogneed.api.predict.bulk.PredictDetectionResponseB\x1f\n\x1b\x61i.cogneed.api.predict.bulkP\x01\x62\x06proto3')
)




_BULKDETECTIONREQUEST = _descriptor.Descriptor(
  name='BulkDetectionRequest',
  full_name='ai.cogneed.api.predict.bulk.BulkDetectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gcs_path', full_name='ai.cogneed.api.predict.bulk.BulkDetectionRequest.gcs_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.predict.bulk.BulkDetectionRequest.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.predict.bulk.BulkDetectionRequest.major', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=170,
)


_PREDICTDETECTIONRESPONSE = _descriptor.Descriptor(
  name='PredictDetectionResponse',
  full_name='ai.cogneed.api.predict.bulk.PredictDetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='ai.cogneed.api.predict.bulk.PredictDetectionResponse.index', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=213,
)

DESCRIPTOR.message_types_by_name['BulkDetectionRequest'] = _BULKDETECTIONREQUEST
DESCRIPTOR.message_types_by_name['PredictDetectionResponse'] = _PREDICTDETECTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BulkDetectionRequest = _reflection.GeneratedProtocolMessageType('BulkDetectionRequest', (_message.Message,), dict(
  DESCRIPTOR = _BULKDETECTIONREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.bulk.bulk_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.bulk.BulkDetectionRequest)
  ))
_sym_db.RegisterMessage(BulkDetectionRequest)

PredictDetectionResponse = _reflection.GeneratedProtocolMessageType('PredictDetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTDETECTIONRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.bulk.bulk_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.bulk.PredictDetectionResponse)
  ))
_sym_db.RegisterMessage(PredictDetectionResponse)


DESCRIPTOR._options = None

_BULKDETECTIONSERVICE = _descriptor.ServiceDescriptor(
  name='BulkDetectionService',
  full_name='ai.cogneed.api.predict.bulk.BulkDetectionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=216,
  serialized_end=361,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetDetections',
    full_name='ai.cogneed.api.predict.bulk.BulkDetectionService.GetDetections',
    index=0,
    containing_service=None,
    input_type=_BULKDETECTIONREQUEST,
    output_type=_PREDICTDETECTIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_BULKDETECTIONSERVICE)

DESCRIPTOR.services_by_name['BulkDetectionService'] = _BULKDETECTIONSERVICE

# @@protoc_insertion_point(module_scope)
