# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/modelconfig/keyword.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/modelconfig/keyword.proto',
  package='ai.cogneed.api.modelconfig.keyword',
  syntax='proto3',
  serialized_options=_b('\n\"ai.cogneed.api.modelconfig.keywordP\001'),
  serialized_pb=_b('\n7cogneed-protos/ai/cogneed/api/modelconfig/keyword.proto\x12\"ai.cogneed.api.modelconfig.keyword\x1a*cogneed-protos/ai/cogneed/api/common.proto\"y\n\rCreateRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x02 \x01(\t\x12>\n\x05usage\x18\x03 \x01(\x0e\x32/.ai.cogneed.api.modelconfig.keyword.UsageOption\"\xd6\x01\n\x0cKeywordUsage\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x12\n\nmodel_uuid\x18\x02 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x03 \x01(\t\x12>\n\x05usage\x18\x04 \x01(\x0e\x32/.ai.cogneed.api.modelconfig.keyword.UsageOption\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\x03\x12\x12\n\nupdated_at\x18\x08 \x01(\x03\"F\n\x0bListRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x15\n\rrows_per_page\x18\x03 \x01(\x05\"b\n\x12UpdateUsageRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12>\n\x05usage\x18\x02 \x01(\x0e\x32/.ai.cogneed.api.modelconfig.keyword.UsageOption\"\x1d\n\rDeleteRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"`\n\x0cListResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x41\n\x07results\x18\x02 \x03(\x0b\x32\x30.ai.cogneed.api.modelconfig.keyword.KeywordUsage*3\n\x0bUsageOption\x12\n\n\x06TARGET\x10\x00\x12\n\n\x06HELPER\x10\x01\x12\x0c\n\x08NEGATIVE\x10\x02\x32\x93\x03\n\x0eKeywordService\x12X\n\x06\x43reate\x12\x31.ai.cogneed.api.modelconfig.keyword.CreateRequest\x1a\x1b.ai.cogneed.api.AckResponse\x12i\n\x04List\x12/.ai.cogneed.api.modelconfig.keyword.ListRequest\x1a\x30.ai.cogneed.api.modelconfig.keyword.ListResponse\x12\x62\n\x0bUpdateUsage\x12\x36.ai.cogneed.api.modelconfig.keyword.UpdateUsageRequest\x1a\x1b.ai.cogneed.api.AckResponse\x12X\n\x06\x44\x65lete\x12\x31.ai.cogneed.api.modelconfig.keyword.DeleteRequest\x1a\x1b.ai.cogneed.api.AckResponseB&\n\"ai.cogneed.api.modelconfig.keywordP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])

_USAGEOPTION = _descriptor.EnumDescriptor(
  name='UsageOption',
  full_name='ai.cogneed.api.modelconfig.keyword.UsageOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TARGET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HELPER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEGATIVE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=780,
  serialized_end=831,
)
_sym_db.RegisterEnumDescriptor(_USAGEOPTION)

UsageOption = enum_type_wrapper.EnumTypeWrapper(_USAGEOPTION)
TARGET = 0
HELPER = 1
NEGATIVE = 2



_CREATEREQUEST = _descriptor.Descriptor(
  name='CreateRequest',
  full_name='ai.cogneed.api.modelconfig.keyword.CreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.modelconfig.keyword.CreateRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.modelconfig.keyword.CreateRequest.keyword_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usage', full_name='ai.cogneed.api.modelconfig.keyword.CreateRequest.usage', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=260,
)


_KEYWORDUSAGE = _descriptor.Descriptor(
  name='KeywordUsage',
  full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.model_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.keyword_uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usage', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.usage', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.created_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_by', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.updated_by', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.created_at', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.updated_at', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=477,
)


_LISTREQUEST = _descriptor.Descriptor(
  name='ListRequest',
  full_name='ai.cogneed.api.modelconfig.keyword.ListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.modelconfig.keyword.ListRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='ai.cogneed.api.modelconfig.keyword.ListRequest.page', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows_per_page', full_name='ai.cogneed.api.modelconfig.keyword.ListRequest.rows_per_page', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=479,
  serialized_end=549,
)


_UPDATEUSAGEREQUEST = _descriptor.Descriptor(
  name='UpdateUsageRequest',
  full_name='ai.cogneed.api.modelconfig.keyword.UpdateUsageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.modelconfig.keyword.UpdateUsageRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usage', full_name='ai.cogneed.api.modelconfig.keyword.UpdateUsageRequest.usage', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=649,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='ai.cogneed.api.modelconfig.keyword.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.modelconfig.keyword.DeleteRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=680,
)


_LISTRESPONSE = _descriptor.Descriptor(
  name='ListResponse',
  full_name='ai.cogneed.api.modelconfig.keyword.ListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='ai.cogneed.api.modelconfig.keyword.ListResponse.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='ai.cogneed.api.modelconfig.keyword.ListResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=778,
)

_CREATEREQUEST.fields_by_name['usage'].enum_type = _USAGEOPTION
_KEYWORDUSAGE.fields_by_name['usage'].enum_type = _USAGEOPTION
_UPDATEUSAGEREQUEST.fields_by_name['usage'].enum_type = _USAGEOPTION
_LISTRESPONSE.fields_by_name['results'].message_type = _KEYWORDUSAGE
DESCRIPTOR.message_types_by_name['CreateRequest'] = _CREATEREQUEST
DESCRIPTOR.message_types_by_name['KeywordUsage'] = _KEYWORDUSAGE
DESCRIPTOR.message_types_by_name['ListRequest'] = _LISTREQUEST
DESCRIPTOR.message_types_by_name['UpdateUsageRequest'] = _UPDATEUSAGEREQUEST
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['ListResponse'] = _LISTRESPONSE
DESCRIPTOR.enum_types_by_name['UsageOption'] = _USAGEOPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateRequest = _reflection.GeneratedProtocolMessageType('CreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.CreateRequest)
  ))
_sym_db.RegisterMessage(CreateRequest)

KeywordUsage = _reflection.GeneratedProtocolMessageType('KeywordUsage', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDUSAGE,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.KeywordUsage)
  ))
_sym_db.RegisterMessage(KeywordUsage)

ListRequest = _reflection.GeneratedProtocolMessageType('ListRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.ListRequest)
  ))
_sym_db.RegisterMessage(ListRequest)

UpdateUsageRequest = _reflection.GeneratedProtocolMessageType('UpdateUsageRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEUSAGEREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.UpdateUsageRequest)
  ))
_sym_db.RegisterMessage(UpdateUsageRequest)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

ListResponse = _reflection.GeneratedProtocolMessageType('ListResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.ListResponse)
  ))
_sym_db.RegisterMessage(ListResponse)


DESCRIPTOR._options = None

_KEYWORDSERVICE = _descriptor.ServiceDescriptor(
  name='KeywordService',
  full_name='ai.cogneed.api.modelconfig.keyword.KeywordService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=834,
  serialized_end=1237,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='ai.cogneed.api.modelconfig.keyword.KeywordService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='ai.cogneed.api.modelconfig.keyword.KeywordService.List',
    index=1,
    containing_service=None,
    input_type=_LISTREQUEST,
    output_type=_LISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateUsage',
    full_name='ai.cogneed.api.modelconfig.keyword.KeywordService.UpdateUsage',
    index=2,
    containing_service=None,
    input_type=_UPDATEUSAGEREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='ai.cogneed.api.modelconfig.keyword.KeywordService.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYWORDSERVICE)

DESCRIPTOR.services_by_name['KeywordService'] = _KEYWORDSERVICE

# @@protoc_insertion_point(module_scope)
