# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api.predict.bulk import bulk_prediction_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_bulk_dot_bulk__prediction__pb2


class BulkDetectionServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetDetections = channel.unary_unary(
        '/ai.cogneed.api.predict.bulk.BulkDetectionService/GetDetections',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_bulk_dot_bulk__prediction__pb2.BulkDetectionRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_bulk_dot_bulk__prediction__pb2.PredictDetectionResponse.FromString,
        )


class BulkDetectionServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetDetections(self, request, context):
    """get all detections from an audio file
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_BulkDetectionServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetDetections': grpc.unary_unary_rpc_method_handler(
          servicer.GetDetections,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_bulk_dot_bulk__prediction__pb2.BulkDetectionRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_bulk_dot_bulk__prediction__pb2.PredictDetectionResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.predict.bulk.BulkDetectionService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
